==> qore-1.8.0.tar.bz2: qore-1.8.0/docs/modules/ConnectionProvider/html/annotated_dup.js <==
var annotated_dup =
[
    [ "ConnectionProvider", "namespace_connection_provider.html", [
      [ "AbstractConnection", "class_connection_provider_1_1_abstract_connection.html", "class_connection_provider_1_1_abstract_connection" ],
      [ "AbstractConnectionWithInfo", "class_connection_provider_1_1_abstract_connection_with_info.html", "class_connection_provider_1_1_abstract_connection_with_info" ],
      [ "AllowedValueInfo", "struct_connection_provider_1_1_allowed_value_info.html", "struct_connection_provider_1_1_allowed_value_info" ],
      [ "ConfigInfo", "struct_connection_provider_1_1_config_info.html", "struct_connection_provider_1_1_config_info" ],
      [ "ConnectionConstructorInfo", "struct_connection_provider_1_1_connection_constructor_info.html", "struct_connection_provider_1_1_connection_constructor_info" ],
      [ "ConnectionInfo", "struct_connection_provider_1_1_connection_info.html", "struct_connection_provider_1_1_connection_info" ],
      [ "ConnectionOptionInfo", "struct_connection_provider_1_1_connection_option_info.html", "struct_connection_provider_1_1_connection_option_info" ],
      [ "ConnectionSchemeCache", "class_connection_provider_1_1_connection_scheme_cache.html", "class_connection_provider_1_1_connection_scheme_cache" ],
      [ "ConnectionSchemeInfo", "struct_connection_provider_1_1_connection_scheme_info.html", "struct_connection_provider_1_1_connection_scheme_info" ],
      [ "FilesystemConnection", "class_connection_provider_1_1_filesystem_connection.html", "class_connection_provider_1_1_filesystem_connection" ],
      [ "FtpConnection", "class_connection_provider_1_1_ftp_connection.html", "class_connection_provider_1_1_ftp_connection" ],
      [ "HttpBasedConnection", "class_connection_provider_1_1_http_based_connection.html", "class_connection_provider_1_1_http_based_connection" ],
      [ "HttpConnection", "class_connection_provider_1_1_http_connection.html", "class_connection_provider_1_1_http_connection" ],
      [ "InvalidConnection", "class_connection_provider_1_1_invalid_connection.html", "class_connection_provider_1_1_invalid_connection" ],
      [ "PingInfo", "struct_connection_provider_1_1_ping_info.html", "struct_connection_provider_1_1_ping_info" ]
    ] ]
];

==> qore-1.12.2.tar.bz2: qore-1.12.2/docs/modules/ConnectionProvider/html/annotated_dup.js <==
var annotated_dup =
[
    [ "ConnectionProvider", "namespace_connection_provider.html", [
      [ "AbstractConnection", "class_connection_provider_1_1_abstract_connection.html", "class_connection_provider_1_1_abstract_connection" ],
      [ "AbstractConnectionWithInfo", "class_connection_provider_1_1_abstract_connection_with_info.html", "class_connection_provider_1_1_abstract_connection_with_info" ],
      [ "AllowedValueInfo", "struct_connection_provider_1_1_allowed_value_info.html", "struct_connection_provider_1_1_allowed_value_info" ],
      [ "ConfigInfo", "struct_connection_provider_1_1_config_info.html", "struct_connection_provider_1_1_config_info" ],
      [ "ConnectionConstructorInfo", "struct_connection_provider_1_1_connection_constructor_info.html", "struct_connection_provider_1_1_connection_constructor_info" ],
      [ "ConnectionInfo", "struct_connection_provider_1_1_connection_info.html", "struct_connection_provider_1_1_connection_info" ],
      [ "ConnectionOptionInfo", "struct_connection_provider_1_1_connection_option_info.html", "struct_connection_provider_1_1_connection_option_info" ],
      [ "ConnectionSchemeCache", "class_connection_provider_1_1_connection_scheme_cache.html", "class_connection_provider_1_1_connection_scheme_cache" ],
      [ "ConnectionSchemeInfo", "struct_connection_provider_1_1_connection_scheme_info.html", "struct_connection_provider_1_1_connection_scheme_info" ],
      [ "FilesystemConnection", "class_connection_provider_1_1_filesystem_connection.html", "class_connection_provider_1_1_filesystem_connection" ],
      [ "FtpConnection", "class_connection_provider_1_1_ftp_connection.html", "class_connection_provider_1_1_ftp_connection" ],
      [ "HttpBasedConnection", "class_connection_provider_1_1_http_based_connection.html", "class_connection_provider_1_1_http_based_connection" ],
      [ "HttpConnection", "class_connection_provider_1_1_http_connection.html", "class_connection_provider_1_1_http_connection" ],
      [ "InvalidConnection", "class_connection_provider_1_1_invalid_connection.html", "class_connection_provider_1_1_invalid_connection" ],
      [ "PingInfo", "struct_connection_provider_1_1_ping_info.html", "struct_connection_provider_1_1_ping_info" ],
      [ "PollingConnectionMonitor", "class_connection_provider_1_1_polling_connection_monitor.html", "class_connection_provider_1_1_polling_connection_monitor" ]
    ] ]
];
